@@ -286,6 +286,8 @@ class Bot:
                 await self._handle_event(evt, event.guild_message_sent, evt.message)
             elif evt.name == "MESSAGE_UPDATE":
                 evt = api.payload.MessageEditEvent(evt)
+                if evt.after == None:
+                    evt.after = self.get_message(evt.data["channel_id"], evt.data["id"])
                 await self._handle_event(evt, event.guild_message_edited, evt.before, evt.after)
             elif evt.name == "MESSAGE_DELETE":
                 evt = api.payload.MessageDeleteEvent(evt)
@@ -438,7 +440,7 @@ class Bot:
             except:
                 pass
             return 0, "KeyboardInterrupt"
-        except (BaseException, asyncio.streams.IncompleteReadError) as e:
+        except (BaseException, asyncio.IncompleteReadError) as e:
             
             if self.stopped:
                 try:
@@ -452,7 +454,7 @@ class Bot:
                 except:
                     pass
             
-            if isinstance(e, asyncio.streams.IncompleteReadError):
+            if isinstance(e, asyncio.IncompleteReadError):
                 self.log("Reconnecting due to an IncompleteReadError: %s" % e)
             else:
                 self.log_error(e)
@@ -592,6 +594,8 @@ class Bot:
             raise error.MessageSendFailure(str(e))
     
     def get_messages(self, channel, n):
+        if isinstance(channel, api.structure.Channel):
+            channel = channel.id
         result, response = self._rate_limited_http(
             "get",
             "https://discord.com/api/v9/channels/%s/messages" % channel,
@@ -614,6 +618,27 @@ class Bot:
         
         return result
     
+    def get_message(self, channel, message_id):
+        if isinstance(channel, api.structure.Channel):
+            channel = channel.id
+        if isinstance(message_id, api.structure.Message):
+            message_id = message_id.id
+        result, response = self._rate_limited_http(
+            "get",
+            "https://discord.com/api/v9/channels/%s/messages/%s" % (channel, message_id),
+            headers = {
+                "Authorization": "Bot %s" % self.token,
+                "Content-Type": "application/json"
+            }
+        )
+        
+        try:
+            result = api.structure.Message(result)
+        except error.InvalidAPIObject as e:
+            raise error.UnexpectedResponse("Response had invalid message w/ error: %s" % (e))
+        
+        return result
+    
     def purge(self, channel, n):
         n = min(max(n, 1), 100)
         if isinstance(channel, api.structure.Channel):
